function getMapDirection() {
	var sourceAdd = $.sourceLocationEditText.value;
	var destAdd = $.destLocationEditText.value;
	getRoute(sourceAdd, destAdd);
}

function getRoute(sourceAdd, destAdd) {
	var url = "http://maps.googleapis.com/maps/api/directions/json?origin=" + sourceAdd +"&destination=" + destAdd + "&sensor=false";
	Ti.API.info(TAG, 'End Point is ' + url);
	var client = Ti.Network.createHTTPClient({
		// function called when the response data is available
		onload : function(e) {
			Ti.API.info("Received text: " + this.responseText);
			drawRoute(this.responseText);
		},
		// function called when an error occurs, including a timeout
		onerror : function(e) {
			hideIndicator();
			Ti.API.debug(e.error);
			alert('error');
		},
		timeout : 5000 // in milliseconds
	});
	// Prepare the connection.
	client.open("GET", url);
	// Send the request.
	showIndicator();
	client.send();
}

function drawRoute(res) {
	var response = JSON.parse(res);
	var points = [], status = response.status;
	var pois = [];
	var status_message = status;
	Ti.API.info(TAG, '>>> status_message is ' + status_message);
	alert('status : '+status_message);
	if (status_message != 'OK') {
		hideIndicator();
		showDirectionErrorDialog('map err no route', 'googlemap error');

	} else {
		var steps = response.routes[0].legs[0].steps, totalSteps = steps.length;
		var end_address = response.routes[0].legs[0].end_address;
		Ti.API.info(TAG, '>>> totalSteps is ' + totalSteps);
		//directin_step.push("Driving Direction to " + end_address);
		for (var i = 0; i < totalSteps; i++) {
			decodedPolyline = decodeLine(steps[i].polyline.points);
			var startLocation = response.routes[0].legs[0].start_address;
			var directionStep = steps[i].html_instructions;
			var time = steps[i].distance.text;

			directin_step.push(directionStep);
			time_step.push(time);
			startLatitude = steps[i].start_location.lat;
			startLongitude = steps[i].start_location.lng;
			pois.push({
				lat : startLatitude,
				lon : startLongitude
			});
			Ti.API.info(TAG, '>>> latitude: ' + startLatitude);
			Ti.API.info(TAG, '>>> longitude: ' + startLongitude);
			for (var j = 0; j < decodedPolyline.length; j++) {
				if (decodedPolyline[j] != null) {
					points.push({
						latitude : decodedPolyline[j][0],
						longitude : decodedPolyline[j][1]
					});
				}
			}
		}

		// Create route and annotations
		var route = Alloy.Globals.Map.createRoute({
			points : points,
			color : "blue",
			width : 6
		}), startAnnotation = Alloy.Globals.Map.createAnnotation({
			pincolor : Alloy.Globals.Map.ANNOTATION_RED,
			latitude : points[0].latitude,
			longitude : points[0].longitude,
			title : $.sourceLocationEditText.value,
		}), endAnnotation = Alloy.Globals.Map.createAnnotation({
			pincolor : Alloy.Globals.Map.ANNOTATION_GREEN,
			latitude : points[points.length - 1].latitude,
			longitude : points[points.length - 1].longitude,
			title : $.destLocationEditText.value,
			//rightButton : "/images/arrow.png"
		});

		var poiCenter = {};
		var delta = 0.02;
		var minLat = pois[0].lat, maxLat = pois[0].lat, minLon = pois[0].lon, maxLon = pois[0].lon;
		for (var i = 0; i < pois.length - 1; i++) {
			minLat = Math.min(pois[i + 1].lat, minLat);
			maxLat = Math.max(pois[i + 1].lat, maxLat);
			minLon = Math.min(pois[i + 1].lon, minLon);
			maxLon = Math.max(pois[i + 1].lon, maxLon);
		}
		var deltaLat = maxLat - minLat;
		var deltaLon = maxLon - minLon;

		delta = Math.max(deltaLat, deltaLon);
		if (deltaLat > deltaLon) {
			delta = delta;
		} else {
			delta = delta + 0.3;
		}

		//delta = delta * 1;

		poiCenter.lat = maxLat - parseFloat((maxLat - minLat) / 2);
		poiCenter.lon = maxLon - parseFloat((maxLon - minLon) / 2);
		$.mapView.region = {
			latitude : poiCenter.lat,
			longitude : poiCenter.lon,
			latitudeDelta : delta,
			longitudeDelta : delta
		};
		// Add elements
		$.mapView.addRoute(route);
		$.mapView.addAnnotation(startAnnotation);
		$.mapView.addAnnotation(endAnnotation);
		//Alloy.Globals.loading_ind.hideIndecator();
		hideIndicator();
		//createDirectionTable();
	}
}
/**
 * This function decode the poly line of route direction
 * @param {Object} encoded polyline string
 */
function decodeLine(encoded) {
	var len = encoded.length;
	var index = 0;
	var array = [];
	var lat = 0;
	var lng = 0;

	while (index < len) {
		var b;
		var shift = 0;
		var result = 0;
		do {
			b = encoded.charCodeAt(index++) - 63;
			result |= (b & 0x1f) << shift;
			shift += 5;
		} while (b >= 0x20);
		var dlat = ((result & 1) ? ~(result >> 1) : (result >> 1));
		lat += dlat;

		shift = 0;
		result = 0;
		do {
			b = encoded.charCodeAt(index++) - 63;
			result |= (b & 0x1f) << shift;
			shift += 5;
		} while (b >= 0x20);
		var dlng = ((result & 1) ? ~(result >> 1) : (result >> 1));
		lng += dlng;

		array.push([lat * 1e-5, lng * 1e-5]);
	}

	return array;
}

/**
 * This function to show direction error dialog
 */
function showDirectionErrorDialog(str, ttl) {

	var alertDialog = Titanium.UI.createAlertDialog({
		message : str,
		title : ttl,
		persistent : true,
		ok : "Ok"
	});
	alertDialog.show();
}

function showIndicator() {
	if (!showingIndicator) {

		progressIndicator = Titanium.UI.Android.createProgressIndicator({
			message : "Loading",
			location : Ti.UI.Android.PROGRESS_INDICATOR_DIALOG,
			type : Ti.UI.Android.PROGRESS_INDICATOR_INDETERMINANT,
			cancelable : false
		});
		progressIndicator.show();
		showingIndicator = true;

	}
}

function hideIndicator() {

	if ((null == progressIndicator) || (false == showingIndicator)) {
		return;
	}
	progressIndicator.hide();
	showingIndicator = false;
	progressIndicator = null;
}
var TAG = "sampleMap";
var progressIndicator;
var showingIndicator = false;
var directin_step = [];
var time_step = [];
var sourceAddr = [];
var destinationAddr = [];
var code = Alloy.Globals.Map.isGooglePlayServicesAvailable();

if (code != Alloy.Globals.Map.SUCCESS) {
	alert ("Google Play Services is not installed/updated/available");
}
$.index.open();
